#!/bin/bash
echo "This script enables the Kinetic Asset Manager 1.6 on Linux to accept"
echo " Panduit SynapSense 900 Series Low Level DSLink sensors for Discovery."
echo ""
echo "NOTE: sudo is used to install the files and set the ownership of the installed directories and files."

EFM_ROOT=/opt/cisco/kinetic
AM_CONFIG=${EFM_ROOT}/efm_manager/config/discovery
AM_WEB_IMAGES=${EFM_ROOT}/efm_manager/web/efm-manager/static/images/products/

if [ ! -d "${AM_CONFIG}" -o ! -d "${AM_WEB_IMAGES}" ]; then
	echo "ERROR: EFM 1.6 does not appear to be installed."
	exit 1
fi


die() {
	STATUS=$?
	if [ $STATUS != 0 ]; then
		echo "ERROR: $STATUS"
		exit $STATUS
	fi
}

# The script copies assets from the same directory as this script.
cd `dirname $0` || die


echo "Installing Discovery files..."
PANDUIT_LINK_ASSETS=`(cd panduit-link-efm16 && find -type f)`
# Who is it installed as?
AM_CONFIG_UID=`stat -c "%U" "${AM_CONFIG}"`
AM_CONFIG_GID=`stat -c "%G" "${AM_CONFIG}"`

sudo install -m 755 -o $AM_CONFIG_UID -g $AM_CONFIG_GID -d ${AM_CONFIG}/panduit-link
for NAME in $PANDUIT_LINK_ASSETS; do
	sudo install -m 644 -o $AM_CONFIG_UID -g $AM_CONFIG_GID panduit-link-efm16/$NAME ${AM_CONFIG}/panduit-link/$NAME || die
done


echo "Installing Web server assets..."
# Who is it installed as?
AM_WEB_IMAGES_UID=`stat -c "%U" ${AM_WEB_IMAGES}`
AM_WEB_IMAGES_GID=`stat -c "%G" ${AM_WEB_IMAGES}`

WEB_NAMES="IOT-9CHT.png IOT-9CTH.png IOT-9CT.png IOT-9CVM.png"
#sudo chmod 755 ${AM_WEB_IMAGES}
for NAME in $WEB_NAMES; do
	sudo install -m 644 -o $AM_WEB_IMAGES_UID -g $AM_WEB_IMAGES_GID products/$NAME ${AM_WEB_IMAGES}/$NAME || die
done


echo "Make the configuration files take effect..."
echo "...Stop asset manager..."
sudo service efm-manager stop
# This seems to wait for the process to die.

echo "...Run load configuration script..."
PID=$$
OFILE=/tmp/install-ss900-am-log.$PID
sudo ${EFM_ROOT}/efm_manager/bin/load-configurations.sh 2>&1 | tee ${OFILE}
# Look for the SUCCESS Message
if egrep -q "(SUCCESS|Configuration is up to date\. Nothing to install)" ${OFILE}; then
	echo "...Start asset manager..."
	sudo service efm-manager start || die
	echo "Done."
	exit 0
else
	echo "ERROR: Please review the messages above for possible errors. EFM Manager is not running."
	exit 1
fi


